@@ -13,7 +13,7 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import List
+from typing import Any, Dict, List, Union
 
 from .literals import (
     AttributeNameType,
@@ -43,37 +43,59 @@ __all__ = (
     "AttributeTypeDef",
     "ComprehendMedicalAsyncJobFilterTypeDef",
     "ComprehendMedicalAsyncJobPropertiesTypeDef",
+    "DescribeEntitiesDetectionV2JobRequestRequestTypeDef",
     "DescribeEntitiesDetectionV2JobResponseTypeDef",
+    "DescribeICD10CMInferenceJobRequestRequestTypeDef",
     "DescribeICD10CMInferenceJobResponseTypeDef",
+    "DescribePHIDetectionJobRequestRequestTypeDef",
     "DescribePHIDetectionJobResponseTypeDef",
+    "DescribeRxNormInferenceJobRequestRequestTypeDef",
     "DescribeRxNormInferenceJobResponseTypeDef",
+    "DetectEntitiesRequestRequestTypeDef",
     "DetectEntitiesResponseTypeDef",
+    "DetectEntitiesV2RequestRequestTypeDef",
     "DetectEntitiesV2ResponseTypeDef",
+    "DetectPHIRequestRequestTypeDef",
     "DetectPHIResponseTypeDef",
     "EntityTypeDef",
     "ICD10CMAttributeTypeDef",
     "ICD10CMConceptTypeDef",
     "ICD10CMEntityTypeDef",
     "ICD10CMTraitTypeDef",
+    "InferICD10CMRequestRequestTypeDef",
     "InferICD10CMResponseTypeDef",
+    "InferRxNormRequestRequestTypeDef",
     "InferRxNormResponseTypeDef",
     "InputDataConfigTypeDef",
+    "ListEntitiesDetectionV2JobsRequestRequestTypeDef",
     "ListEntitiesDetectionV2JobsResponseTypeDef",
+    "ListICD10CMInferenceJobsRequestRequestTypeDef",
     "ListICD10CMInferenceJobsResponseTypeDef",
+    "ListPHIDetectionJobsRequestRequestTypeDef",
     "ListPHIDetectionJobsResponseTypeDef",
+    "ListRxNormInferenceJobsRequestRequestTypeDef",
     "ListRxNormInferenceJobsResponseTypeDef",
     "OutputDataConfigTypeDef",
+    "ResponseMetadataTypeDef",
     "RxNormAttributeTypeDef",
     "RxNormConceptTypeDef",
     "RxNormEntityTypeDef",
     "RxNormTraitTypeDef",
+    "StartEntitiesDetectionV2JobRequestRequestTypeDef",
     "StartEntitiesDetectionV2JobResponseTypeDef",
+    "StartICD10CMInferenceJobRequestRequestTypeDef",
     "StartICD10CMInferenceJobResponseTypeDef",
+    "StartPHIDetectionJobRequestRequestTypeDef",
     "StartPHIDetectionJobResponseTypeDef",
+    "StartRxNormInferenceJobRequestRequestTypeDef",
     "StartRxNormInferenceJobResponseTypeDef",
+    "StopEntitiesDetectionV2JobRequestRequestTypeDef",
     "StopEntitiesDetectionV2JobResponseTypeDef",
+    "StopICD10CMInferenceJobRequestRequestTypeDef",
     "StopICD10CMInferenceJobResponseTypeDef",
+    "StopPHIDetectionJobRequestRequestTypeDef",
     "StopPHIDetectionJobResponseTypeDef",
+    "StopRxNormInferenceJobRequestRequestTypeDef",
     "StopRxNormInferenceJobResponseTypeDef",
     "TraitTypeDef",
     "UnmappedAttributeTypeDef",
@@ -101,8 +123,8 @@ ComprehendMedicalAsyncJobFilterTypeDef = TypedDict(
     {
         "JobName": str,
         "JobStatus": JobStatusType,
-        "SubmitTimeBefore": datetime,
-        "SubmitTimeAfter": datetime,
+        "SubmitTimeBefore": Union[datetime, str],
+        "SubmitTimeAfter": Union[datetime, str],
     },
     total=False,
 )
@@ -128,106 +150,119 @@ ComprehendMedicalAsyncJobPropertiesTypeDef = TypedDict(
     total=False,
 )
 
+DescribeEntitiesDetectionV2JobRequestRequestTypeDef = TypedDict(
+    "DescribeEntitiesDetectionV2JobRequestRequestTypeDef",
+    {
+        "JobId": str,
+    },
+)
+
 DescribeEntitiesDetectionV2JobResponseTypeDef = TypedDict(
     "DescribeEntitiesDetectionV2JobResponseTypeDef",
     {
         "ComprehendMedicalAsyncJobProperties": "ComprehendMedicalAsyncJobPropertiesTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeICD10CMInferenceJobRequestRequestTypeDef = TypedDict(
+    "DescribeICD10CMInferenceJobRequestRequestTypeDef",
+    {
+        "JobId": str,
     },
-    total=False,
 )
 
 DescribeICD10CMInferenceJobResponseTypeDef = TypedDict(
     "DescribeICD10CMInferenceJobResponseTypeDef",
     {
         "ComprehendMedicalAsyncJobProperties": "ComprehendMedicalAsyncJobPropertiesTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribePHIDetectionJobRequestRequestTypeDef = TypedDict(
+    "DescribePHIDetectionJobRequestRequestTypeDef",
+    {
+        "JobId": str,
     },
-    total=False,
 )
 
 DescribePHIDetectionJobResponseTypeDef = TypedDict(
     "DescribePHIDetectionJobResponseTypeDef",
     {
         "ComprehendMedicalAsyncJobProperties": "ComprehendMedicalAsyncJobPropertiesTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+DescribeRxNormInferenceJobRequestRequestTypeDef = TypedDict(
+    "DescribeRxNormInferenceJobRequestRequestTypeDef",
+    {
+        "JobId": str,
     },
-    total=False,
 )
 
 DescribeRxNormInferenceJobResponseTypeDef = TypedDict(
     "DescribeRxNormInferenceJobResponseTypeDef",
     {
         "ComprehendMedicalAsyncJobProperties": "ComprehendMedicalAsyncJobPropertiesTypeDef",
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-_RequiredDetectEntitiesResponseTypeDef = TypedDict(
-    "_RequiredDetectEntitiesResponseTypeDef",
+DetectEntitiesRequestRequestTypeDef = TypedDict(
+    "DetectEntitiesRequestRequestTypeDef",
     {
-        "Entities": List["EntityTypeDef"],
-        "ModelVersion": str,
+        "Text": str,
     },
 )
-_OptionalDetectEntitiesResponseTypeDef = TypedDict(
-    "_OptionalDetectEntitiesResponseTypeDef",
+
+DetectEntitiesResponseTypeDef = TypedDict(
+    "DetectEntitiesResponseTypeDef",
     {
+        "Entities": List["EntityTypeDef"],
         "UnmappedAttributes": List["UnmappedAttributeTypeDef"],
         "PaginationToken": str,
+        "ModelVersion": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
+DetectEntitiesV2RequestRequestTypeDef = TypedDict(
+    "DetectEntitiesV2RequestRequestTypeDef",
+    {
+        "Text": str,
+    },
+)
 
-class DetectEntitiesResponseTypeDef(
-    _RequiredDetectEntitiesResponseTypeDef, _OptionalDetectEntitiesResponseTypeDef
-):
-    pass
-
-
-_RequiredDetectEntitiesV2ResponseTypeDef = TypedDict(
-    "_RequiredDetectEntitiesV2ResponseTypeDef",
+DetectEntitiesV2ResponseTypeDef = TypedDict(
+    "DetectEntitiesV2ResponseTypeDef",
     {
         "Entities": List["EntityTypeDef"],
-        "ModelVersion": str,
-    },
-)
-_OptionalDetectEntitiesV2ResponseTypeDef = TypedDict(
-    "_OptionalDetectEntitiesV2ResponseTypeDef",
-    {
         "UnmappedAttributes": List["UnmappedAttributeTypeDef"],
         "PaginationToken": str,
+        "ModelVersion": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
+DetectPHIRequestRequestTypeDef = TypedDict(
+    "DetectPHIRequestRequestTypeDef",
+    {
+        "Text": str,
+    },
+)
 
-class DetectEntitiesV2ResponseTypeDef(
-    _RequiredDetectEntitiesV2ResponseTypeDef, _OptionalDetectEntitiesV2ResponseTypeDef
-):
-    pass
-
-
-_RequiredDetectPHIResponseTypeDef = TypedDict(
-    "_RequiredDetectPHIResponseTypeDef",
+DetectPHIResponseTypeDef = TypedDict(
+    "DetectPHIResponseTypeDef",
     {
         "Entities": List["EntityTypeDef"],
-        "ModelVersion": str,
-    },
-)
-_OptionalDetectPHIResponseTypeDef = TypedDict(
-    "_OptionalDetectPHIResponseTypeDef",
-    {
         "PaginationToken": str,
+        "ModelVersion": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class DetectPHIResponseTypeDef(
-    _RequiredDetectPHIResponseTypeDef, _OptionalDetectPHIResponseTypeDef
-):
-    pass
-
-
 EntityTypeDef = TypedDict(
     "EntityTypeDef",
     {
@@ -297,50 +332,40 @@ ICD10CMTraitTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredInferICD10CMResponseTypeDef = TypedDict(
-    "_RequiredInferICD10CMResponseTypeDef",
+InferICD10CMRequestRequestTypeDef = TypedDict(
+    "InferICD10CMRequestRequestTypeDef",
+    {
+        "Text": str,
+    },
+)
+
+InferICD10CMResponseTypeDef = TypedDict(
+    "InferICD10CMResponseTypeDef",
     {
         "Entities": List["ICD10CMEntityTypeDef"],
-    },
-)
-_OptionalInferICD10CMResponseTypeDef = TypedDict(
-    "_OptionalInferICD10CMResponseTypeDef",
-    {
         "PaginationToken": str,
         "ModelVersion": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
+InferRxNormRequestRequestTypeDef = TypedDict(
+    "InferRxNormRequestRequestTypeDef",
+    {
+        "Text": str,
+    },
+)
 
-class InferICD10CMResponseTypeDef(
-    _RequiredInferICD10CMResponseTypeDef, _OptionalInferICD10CMResponseTypeDef
-):
-    pass
-
-
-_RequiredInferRxNormResponseTypeDef = TypedDict(
-    "_RequiredInferRxNormResponseTypeDef",
+InferRxNormResponseTypeDef = TypedDict(
+    "InferRxNormResponseTypeDef",
     {
         "Entities": List["RxNormEntityTypeDef"],
-    },
-)
-_OptionalInferRxNormResponseTypeDef = TypedDict(
-    "_OptionalInferRxNormResponseTypeDef",
-    {
         "PaginationToken": str,
         "ModelVersion": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
-
-class InferRxNormResponseTypeDef(
-    _RequiredInferRxNormResponseTypeDef, _OptionalInferRxNormResponseTypeDef
-):
-    pass
-
-
 _RequiredInputDataConfigTypeDef = TypedDict(
     "_RequiredInputDataConfigTypeDef",
     {
@@ -360,6 +385,16 @@ class InputDataConfigTypeDef(_RequiredInputDataConfigTypeDef, _OptionalInputData
     pass
 
 
+ListEntitiesDetectionV2JobsRequestRequestTypeDef = TypedDict(
+    "ListEntitiesDetectionV2JobsRequestRequestTypeDef",
+    {
+        "Filter": "ComprehendMedicalAsyncJobFilterTypeDef",
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
 ListEntitiesDetectionV2JobsResponseTypeDef = TypedDict(
     "ListEntitiesDetectionV2JobsResponseTypeDef",
     {
@@ -367,6 +402,16 @@ ListEntitiesDetectionV2JobsResponseTypeDef = TypedDict(
             "ComprehendMedicalAsyncJobPropertiesTypeDef"
         ],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListICD10CMInferenceJobsRequestRequestTypeDef = TypedDict(
+    "ListICD10CMInferenceJobsRequestRequestTypeDef",
+    {
+        "Filter": "ComprehendMedicalAsyncJobFilterTypeDef",
+        "NextToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
@@ -378,6 +423,16 @@ ListICD10CMInferenceJobsResponseTypeDef = TypedDict(
             "ComprehendMedicalAsyncJobPropertiesTypeDef"
         ],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListPHIDetectionJobsRequestRequestTypeDef = TypedDict(
+    "ListPHIDetectionJobsRequestRequestTypeDef",
+    {
+        "Filter": "ComprehendMedicalAsyncJobFilterTypeDef",
+        "NextToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
@@ -389,6 +444,16 @@ ListPHIDetectionJobsResponseTypeDef = TypedDict(
             "ComprehendMedicalAsyncJobPropertiesTypeDef"
         ],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+ListRxNormInferenceJobsRequestRequestTypeDef = TypedDict(
+    "ListRxNormInferenceJobsRequestRequestTypeDef",
+    {
+        "Filter": "ComprehendMedicalAsyncJobFilterTypeDef",
+        "NextToken": str,
+        "MaxResults": int,
     },
     total=False,
 )
@@ -400,8 +465,8 @@ ListRxNormInferenceJobsResponseTypeDef = TypedDict(
             "ComprehendMedicalAsyncJobPropertiesTypeDef"
         ],
         "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 _RequiredOutputDataConfigTypeDef = TypedDict(
@@ -423,6 +488,17 @@ class OutputDataConfigTypeDef(_RequiredOutputDataConfigTypeDef, _OptionalOutputD
     pass
 
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, Any],
+        "RetryAttempts": int,
+    },
+)
+
 RxNormAttributeTypeDef = TypedDict(
     "RxNormAttributeTypeDef",
     {
@@ -474,68 +550,204 @@ RxNormTraitTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredStartEntitiesDetectionV2JobRequestRequestTypeDef = TypedDict(
+    "_RequiredStartEntitiesDetectionV2JobRequestRequestTypeDef",
+    {
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "OutputDataConfigTypeDef",
+        "DataAccessRoleArn": str,
+        "LanguageCode": Literal["en"],
+    },
+)
+_OptionalStartEntitiesDetectionV2JobRequestRequestTypeDef = TypedDict(
+    "_OptionalStartEntitiesDetectionV2JobRequestRequestTypeDef",
+    {
+        "JobName": str,
+        "ClientRequestToken": str,
+        "KMSKey": str,
+    },
+    total=False,
+)
+
+
+class StartEntitiesDetectionV2JobRequestRequestTypeDef(
+    _RequiredStartEntitiesDetectionV2JobRequestRequestTypeDef,
+    _OptionalStartEntitiesDetectionV2JobRequestRequestTypeDef,
+):
+    pass
+
+
 StartEntitiesDetectionV2JobResponseTypeDef = TypedDict(
     "StartEntitiesDetectionV2JobResponseTypeDef",
     {
         "JobId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredStartICD10CMInferenceJobRequestRequestTypeDef = TypedDict(
+    "_RequiredStartICD10CMInferenceJobRequestRequestTypeDef",
+    {
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "OutputDataConfigTypeDef",
+        "DataAccessRoleArn": str,
+        "LanguageCode": Literal["en"],
+    },
+)
+_OptionalStartICD10CMInferenceJobRequestRequestTypeDef = TypedDict(
+    "_OptionalStartICD10CMInferenceJobRequestRequestTypeDef",
+    {
+        "JobName": str,
+        "ClientRequestToken": str,
+        "KMSKey": str,
     },
     total=False,
 )
 
+
+class StartICD10CMInferenceJobRequestRequestTypeDef(
+    _RequiredStartICD10CMInferenceJobRequestRequestTypeDef,
+    _OptionalStartICD10CMInferenceJobRequestRequestTypeDef,
+):
+    pass
+
+
 StartICD10CMInferenceJobResponseTypeDef = TypedDict(
     "StartICD10CMInferenceJobResponseTypeDef",
     {
         "JobId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredStartPHIDetectionJobRequestRequestTypeDef = TypedDict(
+    "_RequiredStartPHIDetectionJobRequestRequestTypeDef",
+    {
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "OutputDataConfigTypeDef",
+        "DataAccessRoleArn": str,
+        "LanguageCode": Literal["en"],
+    },
+)
+_OptionalStartPHIDetectionJobRequestRequestTypeDef = TypedDict(
+    "_OptionalStartPHIDetectionJobRequestRequestTypeDef",
+    {
+        "JobName": str,
+        "ClientRequestToken": str,
+        "KMSKey": str,
     },
     total=False,
 )
 
+
+class StartPHIDetectionJobRequestRequestTypeDef(
+    _RequiredStartPHIDetectionJobRequestRequestTypeDef,
+    _OptionalStartPHIDetectionJobRequestRequestTypeDef,
+):
+    pass
+
+
 StartPHIDetectionJobResponseTypeDef = TypedDict(
     "StartPHIDetectionJobResponseTypeDef",
     {
         "JobId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+_RequiredStartRxNormInferenceJobRequestRequestTypeDef = TypedDict(
+    "_RequiredStartRxNormInferenceJobRequestRequestTypeDef",
+    {
+        "InputDataConfig": "InputDataConfigTypeDef",
+        "OutputDataConfig": "OutputDataConfigTypeDef",
+        "DataAccessRoleArn": str,
+        "LanguageCode": Literal["en"],
+    },
+)
+_OptionalStartRxNormInferenceJobRequestRequestTypeDef = TypedDict(
+    "_OptionalStartRxNormInferenceJobRequestRequestTypeDef",
+    {
+        "JobName": str,
+        "ClientRequestToken": str,
+        "KMSKey": str,
     },
     total=False,
 )
 
+
+class StartRxNormInferenceJobRequestRequestTypeDef(
+    _RequiredStartRxNormInferenceJobRequestRequestTypeDef,
+    _OptionalStartRxNormInferenceJobRequestRequestTypeDef,
+):
+    pass
+
+
 StartRxNormInferenceJobResponseTypeDef = TypedDict(
     "StartRxNormInferenceJobResponseTypeDef",
+    {
+        "JobId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+StopEntitiesDetectionV2JobRequestRequestTypeDef = TypedDict(
+    "StopEntitiesDetectionV2JobRequestRequestTypeDef",
     {
         "JobId": str,
     },
-    total=False,
 )
 
 StopEntitiesDetectionV2JobResponseTypeDef = TypedDict(
     "StopEntitiesDetectionV2JobResponseTypeDef",
+    {
+        "JobId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+StopICD10CMInferenceJobRequestRequestTypeDef = TypedDict(
+    "StopICD10CMInferenceJobRequestRequestTypeDef",
     {
         "JobId": str,
     },
-    total=False,
 )
 
 StopICD10CMInferenceJobResponseTypeDef = TypedDict(
     "StopICD10CMInferenceJobResponseTypeDef",
+    {
+        "JobId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+StopPHIDetectionJobRequestRequestTypeDef = TypedDict(
+    "StopPHIDetectionJobRequestRequestTypeDef",
     {
         "JobId": str,
     },
-    total=False,
 )
 
 StopPHIDetectionJobResponseTypeDef = TypedDict(
     "StopPHIDetectionJobResponseTypeDef",
+    {
+        "JobId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
+StopRxNormInferenceJobRequestRequestTypeDef = TypedDict(
+    "StopRxNormInferenceJobRequestRequestTypeDef",
     {
         "JobId": str,
     },
-    total=False,
 )
 
 StopRxNormInferenceJobResponseTypeDef = TypedDict(
     "StopRxNormInferenceJobResponseTypeDef",
     {
         "JobId": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
     },
-    total=False,
 )
 
 TraitTypeDef = TypedDict(
